pub struct DownloadSink { /* private fields */ }Expand description
Where a backend writes the downloaded response body.
Child processes (or a std::io::PipeReader) stream bytes into this sink from a worker thread
via DownloadSink::spawn_stdout_drain. If the stream begins with the gzip magic bytes,
bytes are piped through gzip -dc while copying (streaming decompress).
Implementations