RequestBuilder

Struct RequestBuilder 

pub struct RequestBuilder { /* private fields */ }
Builder for a single download request.

Implementations

Source

impl RequestBuilder

pub fn new(url: impl Into<String>) -> Self

Create a new request builder.

pub fn header(self, key: impl Into<String>, value: impl Into<String>) -> Self

Add an HTTP header.

pub fn preferred_downloader(self, preferred: Downloader) -> Self

Prefer a specific downloader backend.

pub fn follow_redirects(self, follow_redirects: bool) -> Self

Enable or disable HTTP redirect following.

pub fn quiet(self, quiet: Quiet) -> Self

Control forwarding of child output.

pub fn fetch_string(self) -> Result<String, ResponseError>

Fetch the response body as a String, blocking until the download is complete.

pub fn fetch_bytes(self) -> Result<Vec<u8>, ResponseError>

Fetch the response body into memory, blocking until the download is complete.

pub fn start( self, target_path: impl AsRef<Path>, ) -> Result<RequestHandle, StartError>

Start the download in a background thread.