pub struct RequestBuilder { /* private fields */ }Expand description
Builder for a single download request.
Implementations
Sourceimpl RequestBuilder
impl RequestBuilder
Sourcepub fn header(self, key: impl Into<String>, value: impl Into<String>) -> Self
pub fn header(self, key: impl Into<String>, value: impl Into<String>) -> Self
Add an HTTP header.
Sourcepub fn preferred_downloader(self, preferred: Downloader) -> Self
pub fn preferred_downloader(self, preferred: Downloader) -> Self
Prefer a specific downloader backend.
Sourcepub fn follow_redirects(self, follow_redirects: bool) -> Self
pub fn follow_redirects(self, follow_redirects: bool) -> Self
Enable or disable HTTP redirect following.
Sourcepub fn fetch_string(self) -> Result<String, ResponseError>
pub fn fetch_string(self) -> Result<String, ResponseError>
Fetch the response body as a String, blocking until the download is complete.
Sourcepub fn fetch_bytes(self) -> Result<Vec<u8>, ResponseError>
pub fn fetch_bytes(self) -> Result<Vec<u8>, ResponseError>
Fetch the response body into memory, blocking until the download is complete.
Sourcepub fn start(
self,
target_path: impl AsRef<Path>,
) -> Result<RequestHandle, StartError>
pub fn start( self, target_path: impl AsRef<Path>, ) -> Result<RequestHandle, StartError>
Start the download in a background thread.